from enum import Enum

class SystemReadingsChannels(Enum):
    Fnx10 = "Fnx10"
    Fn = "Fn"
    Fl = "Fl"
    Ft = "Ft"
    Spare1= "Spare1"
    Spare2= "Spare2"
    It= "It"
    Spare4= "Spare4"
    VHall= "VHall"
    IHall= "IHall"
    Backplane2= "Backplane2"
    Backplane3= "Backplane3"
    Vpd= "Vpd"
    VpdRef= "VpdRef"
    VpdSig= "VpdSig"
    Vbias= "Vbias"
    Lia1RMS= "Lia1RMS"
    Lia1Phase= "Lia1Phase"
    Lia2RMS= "Lia2RMS"
    Lia2Phase= "Lia2Phase"
    FastAdc1= "FastAdc1"
    FastAdc2= "FastAdc2"
    Vz= "Vz"
    DeltaF= "DeltaF"
    Vx= "Vx"
    Vy= "Vy"
    FiberPZT= "FiberPZT"
    ExternalNPX= "ExternalNPX"
    ExternalNPY= "ExternalNPY"
    ExternalNPZ= "ExternalNPZ"
    Spare4_LMT87= "Spare4_LMT87"
    EncoderX = "EncoderX"
    EncoderY = "EncoderY"
    EncoderZ = "EncoderZ"





